********************************************************************************
*                                                                              *
*                  SPSS Program to Score the PIRLS 2016 Items                  *
*                            PIRLS 2016 User Guide                             *
*                                                                              *
********************************************************************************.

SET MPRINT=ON .

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

  * Code for multiple-choice items .

  !IF (!UPCASE(!TYPE)=MC) !THEN
     !DO !I !IN (!ITEM) .
        RECODE !I (!RIGHT = 1      ) /* Item Key         */
                  (!NR    = 0      ) /* Not Reached      */
                  (!NA    = SYSMIS ) /* Not Administered */
                  (!OM    = 0      ) /* Omitted          */
                  (!OTHER = 0      ) /* Other Missing    */
                  (ELSE   = 0      ) .
     !DOEND .
  !IFEND .

  * Code for constructed-response items .

  !IF (!UPCASE(!TYPE)=CR) !THEN
     !DO !I !IN (!ITEM) .
        RECODE !I (3      = 3      ) /* 3 Points         */
                  (2      = 2      ) /* 2 Points         */
                  (1      = 1      ) /* 1 Point          */
                  (0      = 0      ) /* 0 Points         */
                  (!NR    = 0      ) /* Not Reached      */
                  (!NA    = SYSMIS ) /* Not Administered */
                  (!OM    = 0      ) /* Omitted          */
                  (!OTHER = 0      ) /* Other Missing    */
                  (ELSE   = 0      ) .
     !DOEND .
  !IFEND .

!ENDDEFINE .

DEFINE DOIT (INDIR  = !CHAREND('/') /
             OUTDIR = !CHAREND('/') /
             INFILE = !CHAREND('/') ) .

  * Get the student achievement data .

  GET FILE = !QUOTE(!CONCAT(!INDIR,'\',!INFILE,'.SAV')) .

  * Score multiple-choice items with A key .

  SCOREIT TYPE = MC / ITEM = L21B06M   L21B12M   L21E05M   L21E09M   R11F04M
                             R11F11M   R41H05M   R41H12M   R41I06M   R41I08M
                             R11L05M   R31M03M   R31M05M   R31M11M   R41O11M
                             R31W09M   R31W12M   R21Y06M   /
          RIGHT = 1 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with B key .

  SCOREIT TYPE = MC / ITEM = L21B10M   L21E04M   R11F01M   R11F13M   R41H01M
                             R41H10M   R21K06M   R21K09M   R21K11M   R11L02M
                             R31M01M   R31M07M   R31M15M   R41O06M   R41T05M
                             R41T15M   R41T16M   R31W08M   R21Y01M   R21Y04M
                             R21Y05M   R21Y07M   R21Y11M   /
          RIGHT = 2 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with C key .

  SCOREIT TYPE = MC / ITEM = L21B03M   L21B05M   L21B11M   L21B14M   L21E06M
                             L21E08M   R11F02M   R41H07M   R41H11M   R41I05M
                             R41I10M   R21K03M   R11L01M   R11L07M   R11L09M
                             R31M06M   R31M12M   R31M13M   R41O01M   R41T09M
                             R41T12M   R31W03M   R31W05M   R31W06M   R21Y08M /
          RIGHT = 3 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score multiple-choice items with D key .

  SCOREIT TYPE = MC / ITEM = L21B02M   L21E03M   L21E11M   L21E17M   R11F03M
                             R11F05M   R41H02M   R41H09M   R41I02M   R41I12M
                             R21K04M   R21K08M   R11L11M   R31M08M   R31M14M
                             R41O12M   R41T01M   R41T13M   R31W10M   R21Y02M /
          RIGHT = 4 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  * Score Constructed-Response Items .

  SCOREIT TYPE = CR / ITEM = L21B01C   L21B04C   L21B07C   L21B08C   L21B09C
                             L21B13C   L21B15C   L21B16C   L21B17C   L21E01C
                             L21E02C   L21E07C   L21E10C   L21E12C   L21E13C
                             L21E14C   L21E15C   L21E16C   R11F06C   R11F07C
                             R11F08C   R11F09C   R11F10C   R11F12C   R41H03C
                             R41H04C   R41H06C   R41H08C   R41H13C   R41H14C
                             R41H15C   R41H16C   R41I01C   R41I03C   R41I04C
                             R41I07C   R41I09C   R41I11C   R41I13C   R41I14C
                             R41I15C   R21K01C   R21K02C   R21K05C   R21K07C
                             R21K10C   R21K12C   R11L03C   R11L04C   R11L06C
                             R11L08C   R11L10C   R11L12C   R31M02C   R31M04C
                             R31M09C   R31M10C   R31M16C   R31M17CA  R31M17CB
                             R31M17CC  R31M17CZ  R41O02C   R41O03C   R41O04C
                             R41O05C   R41O07C   R41O08C   R41O09C   R41O10C
                             R41O13C   R41T02C   R41T03C   R41T04C   R41T06C
                             R41T07C   R41T08C   R41T10C   R41T11C   R41T14C
                             R31W01C   R31W02C   R31W04C   R31W07CA  R31W07CB
                             R31W07CC  R31W07CZ  R31W11C   R31W13C   R21Y03C
                             R21Y09C   R21Y10C   R21Y12C   R21Y13C   R21Y14C /
          RIGHT = 0 / NR = 6 / NA = SYSMIS / OM = 9 / OTHER = 7 .

  EXECUTE .

  * Save the student data .

  SAVE OUTFILE = !QUOTE(!CONCAT(!OUTDIR,'\',!INFILE,'_SCR.SAV')) .

  NEW FILE .

!ENDDEFINE .

DOIT INDIR  = <Specify location of input SPSS data file using format "x:\xxx"> /
     OUTDIR = <Specify location of output SPSS data file using format "x:\xxx"> /
     INFILE = <Specify name of merged SPSS student achievement data file> .
